/* pieceStandIO.h
 */
#ifndef OSL_PIECESTANDIO_H
#define OSL_PIECESTANDIO_H
#include <iosfwd>
namespace osl
{
  class PieceStand;
  struct PieceStandIO
  {
    /**
     * 持駒の数を空白区切で出力する. 数値処理用途
     */
    static std::ostream& writeNumbers(std::ostream&, const PieceStand& stand);
    static std::istream& readNumbers(std::istream&, PieceStand& stand);
  };
} // namespace osl

#endif /* _PIECESTANDIO_H */
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
